Learn R Programming

Analitica (version 2.2.0)

JBGTest: Jarque-Bera Test with Glinskiy Corrections

Description

Performs the Jarque-Bera test for normality with optional corrections proposed by Glinskiy et al. (2024), depending on whether the mean, variance, or both are known a priori.

Usage

JBGTest(y, mu = NULL, sigma2 = NULL, alpha = 0.05)

Value

An object of class "normalidad", containing:

  • statistic: Test statistic value.

  • df: Degrees of freedom (always 2).

  • p_value: P-value of the test.

  • decision: Conclusion about normality.

  • variant: Type of JB test applied.

  • method: "Jarque-Bera (Glinskiy)"

Arguments

y

A numeric vector to test for normality.

mu

Optional known mean value. Default is NULL.

sigma2

Optional known variance value. Default is NULL.

alpha

Significance level for the test (default is 0.05).

References

Glinskiy, Vladimir & Ismayilova, Yulia & Khrushchev, Sergey & Logachov, Artem & Logachova, Olga & Serga, Lyudmila & Yambartsev, Anatoly & Zaykov, Kirill. (2024). Modifications to the Jarque–Bera Test. Mathematics. 12. 2523. 10.3390/math12162523.

Examples

Run this code

data(d_e, package = "Analitica")
JBGTest(d_e$Sueldo_actual)
#output different of result
summary(JBGTest(d_e$Sueldo_actual))


Run the code above in your browser using DataLab