Learn R Programming

Analitica (version 1.8.5)

plot.comparaciones: Generic plot for multiple comparison tests (with multcompView letters)

Description

This function generates a bar plot displaying group means along with significance letters based on multiple comparisons. It uses multcompView to assign letters indicating statistically different groups.

Usage

# S3 method for comparaciones
plot(x, ...)

Value

No return value. Called for side effects: displays a bar plot with significance letters.

Arguments

x

An object of class comparaciones.

...

Additional arguments (currently not used).

See Also

multcompLetters, ggplot

Examples

Run this code
# Assuming you have an object of class 'comparaciones' named res
# plot(res)

Run the code above in your browser using DataLab