Learn R Programming

Analitica (version 2.2.0)

summary.homocedasticidad: Summary Method for Homoscedasticity Test Results (extended) v2.0

Description

Displays a summary of variance homogeneity tests such as Bartlett, Fligner-Killeen, or Levene (1-via global and if exists, factorial decomposition on |Y - centro_celda|).

Usage

# S3 method for homocedasticidad
summary(object, digits = 4, ...)

Value

Invisibly returns the input object (invisible).

Arguments

object

An object of class "homocedasticidad".

digits

Number of digits for F; default 4.

...

Currently ignored.