Displays a summary of variance homogeneity tests such as Bartlett, Fligner-Killeen, or Levene (1-via global and if exists, factorial decomposition on |Y - centro_celda|).
# S3 method for homocedasticidad
summary(object, digits = 4, ...)Invisibly returns the input object (invisible).
An object of class "homocedasticidad".
Number of digits for F; default 4.
Currently ignored.